@@ -3,19 +3,22 @@ use Mojo::Base 'Mojolicious';
 
 use Data::Dumper;
 
-our $VERSION = '0.008';
+our $VERSION = '0.014';
 
 use File::Basename 'dirname';
+use File::Spec;
 use File::Spec::Functions qw'rel2abs catdir';
 use File::ShareDir 'dist_dir';
 use Cwd;
 
+use Mojo::Home;
+
 has db => sub {
   my $self         = shift;
   my $schema_class = $self->config->{db_schema}
     or die "Unknown DB Schema Class";
   eval "require $schema_class"
-    or die "Could not load Schema Class ($schema_class), $@";
+    or die "Could not load Schema Class ($schema_class), $@\n";
 
   my $db_connect = $self->config->{db_connect}
     or die "No DBI connection string provided";
@@ -27,23 +30,18 @@ has db => sub {
   return $schema;
 };
 
-has app_debug => 1; 
+has app_debug => 0; 
 
-has home_path => sub {
+has home => sub {
   my $path = $ENV{MOJO_HOME} || getcwd;
-  return File::Spec->rel2abs($path);
+  return Mojo::Home->new(File::Spec->rel2abs($path));
 };
 
 has config_file => sub {
   my $self = shift;
   return $ENV{APROJO_CONFIG} if $ENV{APROJO_CONFIG};
 
-  return rel2abs('aprojo.conf', $self->home_path);
-
-#return "$ENV{MOJO_HOME}/timerec.conf" if $ENV{MOJO_HOME};
-#return "$ENV{DOCUMENT_ROOT}/timerec.conf" if $ENV{DOCUMENT_ROOT};
-#return "/var/www/timerec/timerec.conf" if (-f "/var/www/timerec/timerec.conf");
-
+  return $self->home->rel_file('aprojo.conf');
 };
 
 sub startup {
@@ -64,28 +62,28 @@ sub startup {
       },
     }
   );
-
-  $app->plugin('I18N');
-
-  $app->plugin('Mojolicious::Plugin::Form');
   
   {
-    # use content from directories under lib/AproJo/files or using File::ShareDir
+    # use content from directories under share/files or using File::ShareDir
     my $lib_base = catdir(dirname(rel2abs(__FILE__)), '..', 'share','files');
 
     my $public = catdir($lib_base, 'public');
     $app->static->paths->[0] = -d $public ? $public : catdir(dist_dir('AproJo'), 'files','public');
     my $static_path = $app->static->paths->[0];
-    print STDERR '$static_path: ',$static_path,"\n";
+    #print STDERR '$static_path: ',$static_path,"\n";
 
     my $templates = catdir($lib_base, 'templates');
     $app->renderer->paths->[0] = -d $templates ? $templates : catdir(dist_dir('AproJo'), 'files', 'templates');
   }
+  
+  $app->plugin('I18N');
+  $app->plugin('Mojolicious::Plugin::ServerInfo');
+  $app->plugin('Mojolicious::Plugin::DBInfo');
+
+  $app->plugin('Mojolicious::Plugin::Form');
 
   push @{$app->commands->namespaces}, 'AproJo::Command';
 
-  # say STDERR 'namespaces: ', Dumper($app->commands->namespaces);
-
   #DEPRECATED: $app->secret( $app->config->{secret} );
   $app->secrets([$app->config->{secret}]);
 
@@ -122,26 +120,32 @@ sub startup {
         $name = $self->session->{username};
       }
       return undef unless $name;
-      say STDERR 'get_user: ', $name if $self->app->app_debug;
+      #say STDERR 'get_user: ', $name if $self->app->app_debug;
       return $self->schema->resultset('User')->single({name => $name});
     }
   );
+  
+  $app->helper(
+    'has_role' => sub {
+      my $self = shift;
+      my $user_string = shift || '';
+      my $role_string = shift || '';
+      my $user = $self->get_user($user_string);
+      return undef unless $user;
+      my $role = $user->roles()->single({name => $role_string});
+      #say STDERR 'has_role: ', $role->name if $self->app->app_debug;
+      return ($role && $role->name eq $role_string);
+    }
+  );  
   $app->helper(
     'is_admin' => sub {
-      my $self = shift;
-      my $user = $self->get_user(@_);
-      return undef unless $user;
-      # my $role = $user->role->name; 
-      my $role = $user->roles()->single({name => 'admin'});
-      # print STDERR 'is_admin: ', $role, "\n";
-      #return $user->role->name eq 'admin';
-      return ($role && $role->name eq 'admin');
+      my ($self,$user) = @_;
+      return $self->has_role($user,'admin');
     }
   );
 
   my $routes = $app->routes;
 
-  # Normal route to controller
   $routes->get('/')->to('front#index');
   $routes->get('/front/*name')->to('front#page');
   $routes->post('/save')->to('front#save');
@@ -151,15 +155,11 @@ sub startup {
   my $if_admin = $routes->under(
     sub {
       my $self = shift;
-
       return $self->auth_fail unless $self->is_admin;
-
       return 1;
     }
   );
 
-  #$if_admin->get( '/admin/edit/:table/:id' )->to('admin#edit');
-  #$if_admin->get( '/admin/list/:table' )->to('admin#list');
   $if_admin->post('/admin/save/:table')->to('admin#save');
 
   $if_admin->get('/admin/change/:table/:id')->to('admin#change');
@@ -175,6 +175,14 @@ __END__
 
 AproJo - A time recording application based on Mojolicious
 
+=for html
+
+<a href="https://travis-ci.org/wollmers/AproJo"><img src="https://travis-ci.org/wollmers/AproJo.png" alt="AproJo"></a>
+<a href='https://coveralls.io/r/wollmers/AproJo?branch=master'><img src='https://coveralls.io/repos/wollmers/AproJo/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='http://cpants.cpanauthors.org/dist/AproJo'><img src='http://cpants.cpanauthors.org/dist/AproJo.png' alt='Kwalitee Score' /></a>
+<a href="http://badge.fury.io/pl/AproJo"><img src="https://badge.fury.io/pl/AproJo.svg" alt="CPAN version" height="18"></a>
+
+
 =head1 SYNOPSIS
 
  $ aprojo setup
@@ -182,7 +190,11 @@ AproJo - A time recording application based on Mojolicious
 
 =head1 DESCRIPTION
 
-L<AproJo> is a Perl web apllication.
+L<AproJo> is a Perl web application.
+
+=head1 STATUS
+
+L<AproJo> is still in pre-Alpha state. It still misses essential features to be useful in production.
 
 =head1 INSTALLATION
 
@@ -281,15 +293,18 @@ L<Contenticious> - File-based Markdown website application
 
 =head1 SOURCE REPOSITORY
 
-L<http://github.com/wollmers/aprojo>
+L<http://github.com/wollmers/AproJo>
 
 =head1 AUTHOR
 
 Helmut Wollmersdorfer, E<lt>helmut.wollmersdorfer@gmail.comE<gt>
 
+=for html
+<a href='http://cpants.cpanauthors.org/author/wollmers'><img src='http://cpants.cpanauthors.org/author/wollmers.png' alt='Kwalitee Score' /></a>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Helmut Wollmersdorfer
+Copyright (C) 2013-2015 by Helmut Wollmersdorfer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -298,3 +313,4 @@ it under the same terms as Perl itself.
 
 
 
+      
\ No newline at end of file
